==> taskcat-0.9.51.tar.gz: taskcat-0.9.51/taskcat/regions_to_partitions.py <==
REGIONS = {
    "af-south-1": "aws",
    "ap-east-1": "aws",
    "ap-northeast-1": "aws",
    "ap-northeast-2": "aws",
    "ap-northeast-3": "aws",
    "ap-south-1": "aws",
    "ap-south-2": "aws",
    "ap-southeast-1": "aws",
    "ap-southeast-2": "aws",
    "ap-southeast-3": "aws",
    "ap-southeast-4": "aws",
    "ca-central-1": "aws",
    "ca-west-1": "aws",
    "eu-central-1": "aws",
    "eu-central-2": "aws",
    "eu-north-1": "aws",
    "eu-south-1": "aws",
    "eu-south-2": "aws",
    "eu-west-1": "aws",
    "eu-west-2": "aws",
    "eu-west-3": "aws",
    "il-central-1": "aws",
    "me-central-1": "aws",
    "me-south-1": "aws",
    "sa-east-1": "aws",
    "us-east-1": "aws",
    "us-east-2": "aws",
    "us-west-1": "aws",
    "us-west-2": "aws",
    "cn-north-1": "aws-cn",
    "cn-northwest-1": "aws-cn",
    "us-gov-east-1": "aws-us-gov",
    "us-gov-west-1": "aws-us-gov",
    "us-iso-east-1": "aws-iso",
    "us-iso-west-1": "aws-iso",
    "us-isob-east-1": "aws-iso-b",
    "eu-isoe-west-1": "aws-iso-e"
}

PARTITIONS = {
    "aws": [
        "af-south-1",
        "ap-east-1",
        "ap-northeast-1",
        "ap-northeast-2",
        "ap-northeast-3",
        "ap-south-1",
        "ap-south-2",
        "ap-southeast-1",
        "ap-southeast-2",
        "ap-southeast-3",
        "ap-southeast-4",
        "ca-central-1",
        "ca-west-1",
        "eu-central-1",
        "eu-central-2",
        "eu-north-1",
        "eu-south-1",
        "eu-south-2",
        "eu-west-1",
        "eu-west-2",
        "eu-west-3",
        "il-central-1",
        "me-central-1",
        "me-south-1",
        "sa-east-1",
        "us-east-1",
        "us-east-2",
        "us-west-1",
        "us-west-2"
    ],
    "aws-cn": [
        "cn-north-1",
        "cn-northwest-1"
    ],
    "aws-us-gov": [
        "us-gov-east-1",
        "us-gov-west-1"
    ],
    "aws-iso": [
        "us-iso-east-1",
        "us-iso-west-1"
    ],
    "aws-iso-b": [
        "us-isob-east-1"
    ],
    "aws-iso-e": [
        "eu-isoe-west-1"
    ],
    "aws-iso-f": []
}

==> taskcat-0.9.57.tar.gz: taskcat-0.9.57/taskcat/regions_to_partitions.py <==
REGIONS = {
    "af-south-1": "aws",
    "ap-east-1": "aws",
    "ap-northeast-1": "aws",
    "ap-northeast-2": "aws",
    "ap-northeast-3": "aws",
    "ap-south-1": "aws",
    "ap-south-2": "aws",
    "ap-southeast-1": "aws",
    "ap-southeast-2": "aws",
    "ap-southeast-3": "aws",
    "ap-southeast-4": "aws",
    "ap-southeast-5": "aws",
    "ap-southeast-7": "aws",
    "ca-central-1": "aws",
    "ca-west-1": "aws",
    "eu-central-1": "aws",
    "eu-central-2": "aws",
    "eu-north-1": "aws",
    "eu-south-1": "aws",
    "eu-south-2": "aws",
    "eu-west-1": "aws",
    "eu-west-2": "aws",
    "eu-west-3": "aws",
    "il-central-1": "aws",
    "me-central-1": "aws",
    "me-south-1": "aws",
    "mx-central-1": "aws",
    "sa-east-1": "aws",
    "us-east-1": "aws",
    "us-east-2": "aws",
    "us-west-1": "aws",
    "us-west-2": "aws",
    "cn-north-1": "aws-cn",
    "cn-northwest-1": "aws-cn",
    "us-gov-east-1": "aws-us-gov",
    "us-gov-west-1": "aws-us-gov",
    "us-iso-east-1": "aws-iso",
    "us-iso-west-1": "aws-iso",
    "us-isob-east-1": "aws-iso-b",
    "eu-isoe-west-1": "aws-iso-e",
    "us-isof-east-1": "aws-iso-f",
    "us-isof-south-1": "aws-iso-f",
    "eusc-de-east-1": "aws-eusc"
}

PARTITIONS = {
    "aws": [
        "af-south-1",
        "ap-east-1",
        "ap-northeast-1",
        "ap-northeast-2",
        "ap-northeast-3",
        "ap-south-1",
        "ap-south-2",
        "ap-southeast-1",
        "ap-southeast-2",
        "ap-southeast-3",
        "ap-southeast-4",
        "ap-southeast-5",
        "ap-southeast-7",
        "ca-central-1",
        "ca-west-1",
        "eu-central-1",
        "eu-central-2",
        "eu-north-1",
        "eu-south-1",
        "eu-south-2",
        "eu-west-1",
        "eu-west-2",
        "eu-west-3",
        "il-central-1",
        "me-central-1",
        "me-south-1",
        "mx-central-1",
        "sa-east-1",
        "us-east-1",
        "us-east-2",
        "us-west-1",
        "us-west-2"
    ],
    "aws-cn": [
        "cn-north-1",
        "cn-northwest-1"
    ],
    "aws-us-gov": [
        "us-gov-east-1",
        "us-gov-west-1"
    ],
    "aws-iso": [
        "us-iso-east-1",
        "us-iso-west-1"
    ],
    "aws-iso-b": [
        "us-isob-east-1"
    ],
    "aws-iso-e": [
        "eu-isoe-west-1"
    ],
    "aws-iso-f": [
        "us-isof-east-1",
        "us-isof-south-1"
    ],
    "aws-eusc": [
        "eusc-de-east-1"
    ]
}
